package VMOMI::AutoStartWaitHeartbeatSetting;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
